@@ -86,7 +86,7 @@ use constant {    ## no critic (ValuesAndExpressions::ProhibitConstantPragma, Na
   LOG_FORMAT              => qq{ %s [%s] %s\n },
 };
 
-our $VERSION = '1.1.5';
+our $VERSION = '1.1.6';
 
 our @EXPORT_OK = qw{ create_passkey };
 
@@ -1114,7 +1114,10 @@ sub _init_encryption {
     $self->set_encryption(TRUE);
   } ## end if ( $self->get_encrypt...)
   else {
-    my $has_crypt_cbc = eval { require Crypt::CBC; };
+    my $has_crypt_cbc = eval {
+      require Crypt::CBC;
+      require Crypt::Cipher::AES;
+    };
 
     if ( !defined $self->get_encryption ) {
       # let's make the default to encrypt (if we can)
